rm(list=ls())

# Analytical solution of the CFSTR equation
c_t <- function(pars, time) {
  with(as.list(pars), {
    exp(-(qi/v0+k)*time) * (c0 - (qi*ci)/(qi + k*v0)) +
      (qi*ci)/(qi + k*v0)
  })
}

# Inputs
pars <- c(
  c0=10,        # initial concentration
  v0=1.e+05,    # initial volume
  qi=1,         # inflow rate
  ci=1,         # input concentration
  k= 0.5/86400  # decay rate constant
)

# Solution for time of interest
toi <- 3*86400
c_toi <- c_t(pars, time=toi)

# Plot dynamics
times <- seq(from=0, to=1.5*toi, by=3600)
plot(times/3600, c_t(pars,times),
  type="l", xlab="Hours", ylab="c(t)")

# Useful annotations
legend("topright", bty="n", lty=c(1:3),
  legend=c("c(t)","ci","toi"))
abline(h=pars["ci"], lty=2)    # input concentration
abline(v=toi/3600, lty=3)      # time of interest
text(x=toi/3600, y=c_toi, srt=90, adj=-0.5, round(c_toi,2))
