rm(list=ls())

# import data
x <- read.table(file="in/input.txt", sep="", header=TRUE)

# estimate the loss rate constant 'k'
fit <- nls(formula=P_lake ~ P_in / (1 + k*volume/Q_in),
  data=x, start=c(k=0))
stopifnot (fit$convInfo$isConv)
print(fit)

# confidence interval of the estimate
library("MASS")
print(confint(fit))

# extract estimate from fitting object
k <- coef(fit)["k"]

# plot fitted model vs. observations
with(x, {
  plot(x=P_lake, y=P_in / (1 + k*volume/Q_in), log="xy",
    xlab="P_lake obs.", ylab="P_lake model")
})
abline(0,1)

# re-estimate on transformed data
fit <- nls(formula=log(P_lake) ~ log(P_in / (1 + k*volume/Q_in)),
  data=x, start=c(k=0))
stopifnot (fit$convInfo$isConv)
k_log <- coef(fit)["k"]

with(x, {
  matplot(x=cbind(P_lake, P_lake),
    y=cbind(
        P_in / (1 + k*volume/Q_in),      # original model
        P_in / (1 + k_log*volume/Q_in)   # re-fitted model
      ),
    pch=c(1,20), col="black", log="xy",
    xlab="P_lake obs.", ylab="P_lake model")
})
abline(0,1)
legend("bottomright", bty="n", pch=c(1,20),
  legend=c("original fit","log-scale fit"))
